ConfigManager

Struct ConfigManager 

pub struct ConfigManager { /* private fields */ }
Main configuration manager

Implementations

Source

impl ConfigManager

pub async fn new(config_path: impl Into<PathBuf>) -> Result<Self>

Create a new configuration manager

Arguments
  • config_path - Path to the encrypted config file
pub async fn new_with_mock_secrets( config_path: impl Into<PathBuf>, ) -> Result<Self>

Create a new configuration manager with a mock secrets for testing

pub async fn with_sync( config_path: impl Into<PathBuf>, api_url: Option<String>, tenant_id: Option<String>, auto_sync: bool, runtime_mode: RuntimeMode, ) -> Result<Self>

Create a configuration manager with cloud sync enabled

pub async fn load(&self) -> Result<Config>

Load configuration from encrypted file

pub async fn save(&self, config: &Config) -> Result<()>

Save configuration to encrypted file

pub async fn set_secret(&self, key: &str, value: &str) -> Result<()>

Set a secret value Note: With SecretManager, this might fail if not using mock store. Users should set secrets in .env.

pub async fn get_secret(&self, key: &str) -> Result<Option<String>>

Get a secret value

pub async fn delete_secret(&self, key: &str) -> Result<()>

Delete a secret

pub async fn sync_from_cloud(&self) -> Result<Option<Config>>

Sync configuration from cloud

pub async fn sync_to_cloud( &self, config: &Config, ) -> Result<Option<SyncResponse>>

Sync configuration to cloud

pub fn sync_status(&self) -> SyncStatus

Get sync status

pub fn config_path(&self) -> &Path

Get the config file path